CustomSingleSelectField<T> class

Inheritance
Mixed-in types

Constructors

CustomSingleSelectField({Key? key, required List<T> items, required String title, required void onSelectionDone(dynamic value)?, double? width, String itemAsString(dynamic value)?, InputDecoration? decoration, String? validator(String?)?, T? initialValue, Color selectedItemColor = Colors.redAccent})

Properties

decoration → InputDecoration?
final
hashCode → int
The hash code for this object.
no setterinherited
initialValue → T?
final
itemAsString → String Function(dynamic value)?
final
items → List<T>
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onSelectionDone → void Function(dynamic value)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedItemColor → Color
final
title → String
final
validator → String? Function(String?)?
final
width → double?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<CustomSingleSelectField>
Creates the mutable state for this widget at a given location in the tree.
override
customBottomSheet({required BuildContext buildContext, required String headerName, required CustomDropdownButtonType buttonType, required List<CustomMultiSelectDropdownItem<T>> dropdownItems, required List<T> initialSelection, required Color selectedItemColor, bool isAllOptionEnable = false}) → Future<Map<String, List<T>?>>
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited